@@ -9,14 +9,16 @@ import sys
 import asyncio
 from typing import Any, Dict, Tuple, Optional
 
-from .exception import NetworkError
-
 
 class ResultStore:
     def __init__(self) -> None:
         self._seq: int = 1
         self._futures: Dict[Tuple[str, int], asyncio.Future] = {}
 
+    @property
+    def current_seq(self) -> int:
+        return self._seq
+
     def get_seq(self) -> int:
         s = self._seq
         self._seq = (self._seq + 1) % sys.maxsize
@@ -36,7 +38,5 @@ class ResultStore:
         self._futures[(self_id, seq)] = future
         try:
             return await asyncio.wait_for(future, timeout)
-        except asyncio.TimeoutError:
-            raise NetworkError("WebSocket API call timeout") from None
         finally:
             del self._futures[(self_id, seq)]
