@@ -12,7 +12,7 @@ import contextlib
 from typing import Any, Dict, List, Type, Union, Callable, Optional, Generator, cast
 
 import msgpack
-from pygtrie import StringTrie
+from pygtrie import CharTrie
 from nonebot.typing import overrides
 from nonebot.utils import escape_tag
 from nonebot.exception import WebSocketClosed
@@ -31,20 +31,20 @@ from nonebot.drivers import (
 from nonebot.adapters import Adapter as BaseAdapter
 from nonebot.adapters.onebot.collator import Collator
 from nonebot.adapters.onebot.store import ResultStore
-from nonebot.adapters.onebot.exception import NetworkError, ApiNotAvailable
-from nonebot.adapters.onebot.utils import (
-    CustomEncoder,
-    get_auth_bearer,
-    handle_api_result,
-    flattened_to_nested,
-)
+from nonebot.adapters.onebot.utils import get_auth_bearer
 
-from . import event
 from .bot import Bot
-from .log import log
 from .event import Event
 from .config import Config
+from . import event, exception
 from .message import Message, MessageSegment
+from .utils import CustomEncoder, log, flattened_to_nested
+from .exception import (
+    NetworkError,
+    ApiNotAvailable,
+    ActionMissingField,
+    ActionFailedWithRetcode,
+)
 
 RECONNECT_INTERVAL = 3.0
 COLLATOR_KEY = ("type", "detail_type", "sub_type")
@@ -55,14 +55,26 @@ for model_name in dir(event):
         continue
     DEFAULT_MODELS.append(model)
 
+DEFAULT_EXCEPTIONS: List[Type[ActionFailedWithRetcode]] = []
+for exc_name in dir(exception):
+    Exc = getattr(exception, exc_name)
+    if not inspect.isclass(Exc) or not issubclass(Exc, ActionFailedWithRetcode):
+        continue
+    DEFAULT_EXCEPTIONS.append(Exc)
+
 
 class Adapter(BaseAdapter):
 
-    event_models: StringTrie = StringTrie(separator="/")
-    event_models[""] = Collator(
-        "OneBot V12",
-        DEFAULT_MODELS,
-        COLLATOR_KEY,
+    event_models: Dict[str, Collator[Event]] = {
+        "": Collator(
+            "OneBot V12",
+            DEFAULT_MODELS,
+            COLLATOR_KEY,
+        )
+    }
+
+    exc_classes: CharTrie = CharTrie(
+        (retcode, Exc) for Exc in DEFAULT_EXCEPTIONS for retcode in Exc.__retcode__
     )
 
     _result_store = ResultStore()
@@ -144,9 +156,12 @@ class Adapter(BaseAdapter):
                 cls=CustomEncoder,
             )
             await websocket.send(json_data)
-            return handle_api_result(
-                await self._result_store.fetch(bot.self_id, seq, timeout)
-            )
+            try:
+                return self._handle_api_result(
+                    await self._result_store.fetch(bot.self_id, seq, timeout)
+                )
+            except asyncio.TimeoutError:
+                raise NetworkError(f"WebSocket call api {api} timeout") from None
 
         elif isinstance(self.driver, ForwardDriver):
             api_url = self.onebot_config.onebot_api_roots.get(bot.self_id)
@@ -174,7 +189,7 @@ class Adapter(BaseAdapter):
                     if not response.content:
                         raise ValueError("Empty response")
                     result = json.loads(response.content)
-                    return handle_api_result(result)
+                    return self._handle_api_result(result)
                 raise NetworkError(
                     f"HTTP request received unexpected "
                     f"status code: {response.status_code}"
@@ -186,6 +201,35 @@ class Adapter(BaseAdapter):
         else:
             raise ApiNotAvailable
 
+    def _handle_api_result(self, result: Any) -> Any:
+        """处理 API 请求返回值。
+
+        参数:
+            result: API 返回数据
+
+        返回:
+            API 调用返回数据
+
+        异常:
+            ActionFailed: API 调用失败
+        """
+        if not isinstance(result, dict):
+            raise ActionMissingField(result)
+        elif not set(result.keys()).issuperset(
+            {"status", "retcode", "data", "message"}
+        ):
+            raise ActionMissingField(result)
+
+        if result["status"] == "failed":
+            retcode = result["retcode"]
+            if not isinstance(retcode, int):
+                raise ActionMissingField(result)
+
+            Exc = self.get_exception(retcode)
+
+            raise Exc(**result)
+        return result["data"]
+
     async def _handle_http(self, request: Request) -> Response:
         self_id = request.headers.get("x-self-id")
 
@@ -254,7 +298,8 @@ class Adapter(BaseAdapter):
         except Exception as e:
             log(
                 "ERROR",
-                f"<r><bg #f8bbd0>Error while process data from websocketfor bot {escape_tag(self_id)}.</bg #f8bbd0></r>",
+                "<r><bg #f8bbd0>Error while process data from websocket "
+                f"for bot {escape_tag(self_id)}.</bg #f8bbd0></r>",
                 e,
             )
 
@@ -386,11 +431,28 @@ class Adapter(BaseAdapter):
     ) -> Generator[Type[Event], None, None]:
         """根据事件获取对应 `Event Model` 及 `FallBack Event Model` 列表。"""
         key = f"/{data.get('impl')}/{data.get('platform')}"
-        platform_collator: Collator[Event]
-        for platform_collator in reversed(
-            [c.value for c in cls.event_models.prefixes(key)]
-        ):
-            yield from platform_collator.get_model(data)
+        if key in cls.event_models:
+            yield from cls.event_models[key].get_model(data)
+        yield from cls.event_models[""].get_model(data)
+
+    @classmethod
+    def add_custom_exception(cls, exc: Type[ActionFailedWithRetcode]):
+        for retcode in exc.__retcode__:
+            if retcode in cls.exc_classes:
+                log(
+                    "WARNING",
+                    f"Exception for retcode {retcode} is is overridden by {exc}",
+                )
+            cls.exc_classes[retcode] = exc
+
+    @classmethod
+    def get_exception(cls, retcode: int) -> Type[ActionFailedWithRetcode]:
+        if retcode < 100000:
+            Exc = cls.exc_classes.longest_prefix(str(retcode).rjust(5, "0"))
+            Exc = Exc.value if Exc else ActionFailedWithRetcode
+        else:
+            Exc = ActionFailedWithRetcode
+        return Exc
 
     @classmethod
     def json_to_event(
